#!/bin/bash

# vars
CERT_NAME=""
DEST_DIR=""

#getopts
args=$(getopt -n $0 -o "hn:d:" --long "help,name:,dest:" -- "$@")

eval set -- "$args"

if [ $? -ne 0 ]; then
    ./$0 -h
    exit 1
fi


while true;
do
    case "$1" in
        -h|--help)
            echo "Usage: $0 [-n CERTNAME] [-d DESTINATION] "
            echo ""
            echo "options:      '-h|--help' shows this"
            echo "              '-n|--name' this will be the name of your cert file"
            echo "              '-d|--dest' folder were to save all related files"
            echo "                          (will be created)"
            shift
            exit 0
        ;;
        -n|--name)
            if [ -n "$2" ];
            then
                CERT_NAME=$2
                shift 2
            else
                echo "use '-n CERTNAME'"
                exit 1
            fi
        ;;
        -d|--dest)
            if [ -n "$2" ];
            then
                DEST_DIR=$2
                shift 2
            else
                echo "use '-n DESTINATION'"
                exit 1
            fi
        ;;        --)
            shift
            break
        ;;
        *)
            shift
        ;;
    esac
done

if [ $DEST_DIR = "" ] || [ $CERT_NAME = "" ]; then
    echo "No Destination and No Certname given..."
    ./$0 -h
    exit 1
fi

mkdir $DEST_DIR
cd $DEST_DIR
openssl genrsa -des3 -out $CERT_NAME.key 1024
openssl req -config ../cert.cnf -new -key $CERT_NAME.key -out $CERT_NAME.csr
cp $CERT_NAME.key $CERT_NAME.key.orig
openssl rsa -in $CERT_NAME.key -out $CERT_NAME.key
openssl x509 -req -days 3650 -extensions v3_req -extfile ../cert.cnf -in $CERT_NAME.csr -signkey $CERT_NAME.key -out $CERT_NAME.crt
openssl x509 -in $CERT_NAME.crt -out $CERT_NAME.der -outform DER
openssl x509 -in $CERT_NAME.der -inform DER -out $CERT_NAME.pem -outform PEM
cd -
